# twitcaspy
[![license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/Alma-field/twitcaspy/blob/master/LICENSE)
[![test](https://github.com/Alma-field/twitcaspy/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/Alma-field/twitcaspy/actions/workflows/test.yml)
[![Deploy](https://github.com/Alma-field/twitcaspy/actions/workflows/deploy.yml/badge.svg)](https://github.com/Alma-field/twitcaspy/actions/workflows/deploy.yml)
[![Documentation Status](https://readthedocs.org/projects/twitcaspy/badge/?version=latest)](http://twitcaspy.alma-field.com/en/latest/?badge=latest)
[![GitHub issues open](https://img.shields.io/github/issues/Alma-field/twitcaspy.svg)](https://github.com/Alma-field/twitcaspy/issues?q=is%3Aopen+is%3Aissue)
[![GitHub issues close](https://img.shields.io/github/issues-closed-raw/Alma-field/twitcaspy.svg)](https://github.com/Alma-field/twitcaspy/issues?q=is%3Aclose+is%3Aissue)
[![PyPI Version](https://img.shields.io/pypi/v/twitcaspy?label=PyPI)](https://pypi.org/project/twitcaspy/)
[![Python Versions](https://img.shields.io/pypi/pyversions/twitcaspy?label=Python)](https://pypi.org/project/twitcaspy/)

Twitcatting for Python

## Other language version
 - [English](https://github.com/Alma-field/twitcaspy/blob/master/README.md)
 - [Japanese](https://github.com/Alma-field/twitcaspy/blob/master/README_JA.md)

## Document
 - [latest (v1.0.1)](https://twitcaspy.alma-field.com/en/latest)
 - [v1.0.1](https://twitcaspy.alma-field.com/en/1.0.1)

## Installation
The easiest way to install the latest version from PyPI is by using pip:
```
pip install twitcaspy
```

You can also use Git to clone the repository from GitHub to install the latest
development version:
```
git clone https://github.com/Alma-field/twitcaspy.git
cd twitcaspy
pip install .
```

Alternatively, install directly from the GitHub repository:
```
pip install git+https://github.com/Alma-field/twitcaspy.git
```

Python 3.7 - 3.9 are supported.

## Source
This library is based on:
 - [tweepy/tweepy](https://github.com/tweepy/tweepy) - Twitter for Python!
 - [tamago324/PyTwitcasting](https://github.com/tamago324/PyTwitcasting) - PyTwitcasting is a library for API v2 (β) of Twitcasting.

## Links
 - [Twitcasting API Documentation](https://apiv2-doc.twitcasting.tv/)
 - [API ChangeLog](https://github.com/twitcasting/PublicApiV2/blob/master/CHANGELOG.md)
